@@ -35,7 +35,7 @@ NULL
 is_pre_release <- function(x) {
   if (!is_smvr(x)) {
     cli::cli_abort(
-      "{.code is_pre_release()} only works with {.code smvr} objects."
+      "{.fn is_pre_release()} only works with {.pkg smvr} objects."
     )
   }
   !(field(x, "pre_release") |> field("is_empty"))
@@ -46,7 +46,7 @@ is_pre_release <- function(x) {
 has_build_metadata <- function(x) {
   if (!is_smvr(x)) {
     cli::cli_abort(
-      "{.code has_build_metadata()} only works with {.code smvr} objects."
+      "{.fn has_build_metadata()} only works with {.pkg smvr} objects."
     )
   }
   nzchar(field(x, "build"), keepNA = TRUE)
